@@ -61,7 +61,9 @@ struct _PtyxisPreferencesWindow
   GtkLabel             *font_name;
   AdwActionRow         *font_name_row;
   AdwSwitchRow         *limit_scrollback;
+  AdwSwitchRow         *login_shell;
   GtkAdjustment        *opacity_adjustment;
+  AdwPreferencesGroup  *opacity_group;
   GtkLabel             *opacity_label;
   GtkFlowBox           *palette_previews;
   AdwComboRow          *preserve_directory;
@@ -403,6 +405,13 @@ ptyxis_preferences_window_notify_default_profile_cb (PtyxisPreferencesWindow *se
                            self,
                            G_CONNECT_SWAPPED);
 
+  /* If the user changed things in gsettings, show the toggle. This
+   * also helps on installations where the distributor may have changed
+   * the default value for the opacity gsetting.
+   */
+  gtk_widget_set_visible (GTK_WIDGET (self->opacity_group),
+                          ptyxis_profile_get_opacity (profile) < 1.);
+
   invalidate_filter (self);
 
   for (GtkWidget *child = gtk_widget_get_first_child (GTK_WIDGET (self->palette_previews));
@@ -447,6 +456,9 @@ ptyxis_preferences_window_notify_default_profile_cb (PtyxisPreferencesWindow *se
   g_object_bind_property (profile, "bold-is-bright",
                           self->bold_is_bright, "active",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+  g_object_bind_property (profile, "login-shell",
+                          self->login_shell, "active",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
   g_settings_bind_with_mapping (gsettings,
                                 PTYXIS_PROFILE_KEY_BACKSPACE_BINDING,
@@ -926,7 +938,9 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, font_name);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, font_name_row);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, limit_scrollback);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, login_shell);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, opacity_adjustment);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, opacity_group);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, opacity_label);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, palette_previews);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, preserve_directories);
